//go:build !darwin
// +build !darwin

package secret

import (
	"filippo.io/age"
	"github.com/awnumar/memguard"
	"github.com/spf13/afero"
)

// KeychainUnlockerMetadata is a stub for non-Darwin platforms
type KeychainUnlockerMetadata struct {
	UnlockerMetadata
	KeychainItemName string `json:"keychainItemName"`
}

// KeychainUnlocker is a stub for non-Darwin platforms
type KeychainUnlocker struct {
	Directory string
	Metadata  UnlockerMetadata
	fs        afero.Fs
}

// GetIdentity panics on non-Darwin platforms
func (k *KeychainUnlocker) GetIdentity() (*age.X25519Identity, error) {
	panic("keychain unlockers are only supported on macOS")
}

// GetType panics on non-Darwin platforms
func (k *KeychainUnlocker) GetType() string {
	panic("keychain unlockers are only supported on macOS")
}

// GetMetadata panics on non-Darwin platforms
func (k *KeychainUnlocker) GetMetadata() UnlockerMetadata {
	panic("keychain unlockers are only supported on macOS")
}

// GetDirectory panics on non-Darwin platforms
func (k *KeychainUnlocker) GetDirectory() string {
	panic("keychain unlockers are only supported on macOS")
}

// GetID returns the unlocker ID
func (k *KeychainUnlocker) GetID() string {
	panic("keychain unlockers are only supported on macOS")
}

// GetKeychainItemName panics on non-Darwin platforms
func (k *KeychainUnlocker) GetKeychainItemName() (string, error) {
	panic("keychain unlockers are only supported on macOS")
}

// Remove panics on non-Darwin platforms
func (k *KeychainUnlocker) Remove() error {
	panic("keychain unlockers are only supported on macOS")
}

// NewKeychainUnlocker panics on non-Darwin platforms
func NewKeychainUnlocker(fs afero.Fs, directory string, metadata UnlockerMetadata) *KeychainUnlocker {
	panic("keychain unlockers are only supported on macOS")
}

// CreateKeychainUnlocker panics on non-Darwin platforms
func CreateKeychainUnlocker(fs afero.Fs, stateDir string) (*KeychainUnlocker, error) {
	panic("keychain unlockers are only supported on macOS")
}

// getLongTermPrivateKey panics on non-Darwin platforms
func getLongTermPrivateKey(fs afero.Fs, vault VaultInterface) (*memguard.LockedBuffer, error) {
	panic("keychain unlockers are only supported on macOS")
}
